@@ -1,7 +1,7 @@
 #!/usr/local/bin/python2.7
 # -*- coding: utf-8 -*-
 #
-# (c) Copyright 2001-2009 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2001-2015 HP Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -585,6 +585,12 @@ class SetupDialog(QDialog, Ui_Dialog):
             self.DevicesFoundIcon.setPixmap(load_pixmap('error', '16x16'))
             log.error("No devices found on bus: %s" % self.bus)
             self.DevicesFoundLabel.setText(self.__tr("<b>No devices found.</b><br>Click <i>Back</i> to change discovery options, or <i>Refresh</i> to search again."))
+            if self.bus == 'net' and utils.check_lan():
+                FailureUI(self, self.__tr('''<b>HPLIP cannot detect printers in your network.</b><p>This may be due to existing firewall settings blocking the required ports.
+                When you are in a trusted network environment, you may open the ports for network services like mdns and slp in the firewall. For detailed steps follow the link.
+                <b>http://hplipopensource.com/node/374</b></p>'''),
+                        self.__tr("HP Device Manager"))
+            
 
         self.displayPage(PAGE_DEVICES)
 
